@@ -18,8 +18,7 @@ import os
 import subprocess
 import sys
 
-from . import VERSION
-from .conf import PathConfig
+from .conf import VERSION, PathConfig
 from .exceptions import RunCmdError
 from .exceptions import SystemTypeError
 from .utils.printer import print_error
